@@ -1,10 +1,10 @@
 from typing import Any, Optional
 
-from pydantic import Field
+from pydantic import Field, validator
 
 from dictum_core.schema.id import ID
 from dictum_core.schema.model.format import Formatted
-from dictum_core.schema.model.type import Type
+from dictum_core.schema.model.types import Type, resolve_type
 
 
 class Displayed(Formatted):
@@ -14,13 +14,19 @@ class Displayed(Formatted):
     type: Type
     missing: Optional[Any]
 
+    @validator("type", pre=True)
+    def resolve_type(cls, value):
+        if isinstance(value, str):
+            return resolve_type(value)
+        return value
+
 
 class Calculation(Displayed):
     str_expr: str = Field(..., alias="expr")
 
 
 class AggregateCalculation(Calculation):
-    type: Type = "float"
+    type: Type = Type(name="float")
     str_filter: Optional[str] = Field(alias="filter")
     str_time: Optional[str] = Field(alias="time")
 
