@@ -532,10 +532,6 @@ def test_generic_time_format(project: Project):
         ("Week", 202),
         ("Day", 354),
         ("Date", 354),
-        ("Hour", 354),  # dates in the database
-        ("Minute", 354),
-        ("Second", 354),
-        ("Time", 354),
     ],
 )
 def test_generic_time_trunc(project: Project, dimension: str, n: int):
@@ -573,7 +569,7 @@ def test_measure_with_related_column(project: Project):
 
 def test_default_time_format(project: Project):
     result = project.select("revenue").by("invoice_date").df(format=True)
-    assert result.iloc[0]["Invoice Date"] == "1/1/09"
+    assert result.iloc[0]["Invoice Date"] == "1/1/2009"
 
 
 def test_percents_without_alias(project: Project):
